@@ -123,6 +123,14 @@ def setup_code_generation(
             M = (Identity(N) - h * el0 * J).as_mutable()
             cache.store(("jacobian", permutation), (J, h, el0, M))
 
+    count_nz = sum(1 for i in range(M.rows) for j in range(M.rows) if M[i, j] != 0)
+    print(
+        "n=",
+        M.rows,
+        "non zeros:",
+        count_nz,
+        "sparsity: %.3f %%" % (100 * count_nz / M.rows ** 2),
+    )
     return cache, J, h, el0, M, rhs
 
 
@@ -1185,8 +1193,8 @@ def main():
     rhs = Matrix(
         [
             -0.04 * y0 + 1e4 * y1 * y2,
-            0.04 * y0 - 1e4 * y1 * y2 - 3e7 * y1**2,
-            3e7 * y1**2,
+            0.04 * y0 - 1e4 * y1 * y2 - 3e7 * y1 ** 2,
+            3e7 * y1 ** 2,
         ]
     )
 
