@@ -23,7 +23,7 @@ from .expressions import Max, Min, isnan
 from .function import Alias, Function, function_wrapper_factory
 from .globals import Globals
 from .integral import ERROR, Checked, IfThenElse, Integral
-from .interpolation import InterpolationFunction1D
+from .interpolation import InterpolationFunction1D, InterpolationFunction1DWrapper
 from .ode import Ode
 from .ode_combined import OdeCombined
 from .ode_fast import OdeFast, read_known_traces, read_new_traces, write_known_traces
@@ -430,6 +430,32 @@ class ModuleWrapper(WrapperBase):
 
         yield from self.fast_ode_unique_id_function()
 
+        yield self._pickling_code()
+
+    def _pickling_code(self):
+        names = []
+        for name, w in self.visitor.extra_wrappers.items():
+            if isinstance(w, InterpolationFunction1DWrapper):
+                names.append(str(name))
+
+        return align(
+            f"""
+                |def __getstate__():
+                |    data = [(name,
+                |             eval("get_x_" + name + "()"),
+                |             eval("get_y_" + name + "()"))
+                |    for name in {names!r}]
+                |    # print("get state", data)
+                |    return data
+                |
+                |def __setstate__(data):
+                |    # print("set state", data)
+                |    for name, x, y in data:
+                |         if x is not None:
+                |             eval("set_" + name + "_values(x, y)")
+                """
+        )
+
     def fast_ode_unique_id_function(self):
         unique_ids = {
             wrapper.name: wrapper.ode.get_unique_id()
